==> plplot-c++-5.6.1p1.tgz: share/examples/plplot/test_cxx.sh <==
#!/bin/sh
#
# Test suite for c++ examples.
#
# Copyright (C) 2004  Alan W. Irwin
# Copyright (C) 2004  Andrew Ross
#
# This file is part of PLplot.
#
# PLplot is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Library Public License as published
# by the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# PLplot is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU Library General Public License
# along with PLplot; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

# This is called from plplot-test.sh with $cxxdir, $device, $dsuffix,
# and $options defined.

# To build the c++ examples before running this script do the following:
# pushd $cxxdir; make; popd

# x01cc is a C++ alternative that has no corresponding examples for the
# other front ends.
$cxxdir/x01cc -dev $device -o ${OUTPUT_DIR}/x01cc.$dsuffix $options

# Do the standard non-interactive examples.
# skip 14 because it requires two output files.
# skip 17 and 20 because they are interactive.
# skip 21 because it delivers variable results depending on computer timing
# and load.
for index in 01 02 03 04 05 06 07 08 09 10 11 12 13 15 16 18 19 22 23; do
  $cxxdir/x${index} -dev $device -o ${OUTPUT_DIR}/x${index}cxx.$dsuffix $options
done

==> plplot-c++-5.8.0p9.tgz: share/examples/plplot/test_cxx.sh <==
#!/usr/local/bin/bash
#
# Test suite for c++ examples.
#
# Copyright (C) 2004  Alan W. Irwin
# Copyright (C) 2004  Andrew Ross
#
# This file is part of PLplot.
#
# PLplot is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Library Public License as published
# by the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# PLplot is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU Library General Public License
# along with PLplot; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

# This is called from plplot-test.sh with $cxxdir, $device, $dsuffix,
# and $options defined.

# To build the c++ examples before running this script do the following:
# pushd $cxxdir; make; popd

# x01cc is a C++ alternative that has no corresponding examples for the
# other front ends.
$cxxdir/x01cc -dev $device -o ${OUTPUT_DIR}/x01cc.$dsuffix $options

# Do the standard non-interactive examples.
# skip 14 because it requires two output files.
# skip 17 because it is interactive.
for index in 01 02 03 04 05 06 07 08 09 10 11 12 13 15 16 18 19 20 21 22 23 24 25 26 28; do
  $cxxdir/x${index} -dev $device -o ${OUTPUT_DIR}/x${index}cxx.$dsuffix $options 2> test.error
  status_code=$?
  cat test.error
  if [ "$status_code" -ne 0 ]; then
    exit $status_code
  fi
  # Look for any PLPLOT ERROR messages from plwarn that do not result in an
  # exit code.
  is_error=`grep -l 'PLPLOT ERROR' test.error`
  if test -n "$is_error"; then
    exit 1
  fi
done
